@@ -4,13 +4,14 @@ control.py - Implements SHUTDOWN and REHASH functionality.
 import atexit
 import os
 import signal
-import sys
 import threading
 
 from pylinkirc import conf, utils, world  # Do not import classes, it'll import loop
 from pylinkirc.log import _get_console_log_level, _make_file_logger, _stop_file_loggers, log
 
-from . import login, permissions
+from . import login
+
+__all__ = ['remove_network', 'shutdown', 'rehash']
 
 
 def remove_network(ircobj):
