@@ -2,12 +2,14 @@
 permissions.py - Permissions Abstraction for PyLink IRC Services.
 """
 
-import threading
 from collections import defaultdict
 
 from pylinkirc import conf, utils
 from pylinkirc.log import log
 
+__all__ = ['default_permissions', 'add_default_permissions',
+           'remove_default_permissions', 'check_permissions']
+
 # Global variables: these store mappings of hostmasks/exttargets to lists of permissions each target has.
 default_permissions = defaultdict(set)
 
