@@ -1,16 +1,12 @@
 """
 exec.py: Provides commands for executing raw code and debugging PyLink.
 """
-import importlib
 import pprint
 # These imports are not strictly necessary, but make the following modules
 # easier to access through eval and exec.
-import re
 import threading
-import time
 
-import pylinkirc
-from pylinkirc import *
+from pylinkirc import utils, world, conf
 from pylinkirc.coremods import permissions
 from pylinkirc.log import log
 
@@ -18,6 +14,11 @@ exec_locals_dict = {}
 PPRINT_MAX_LINES = 20
 PPRINT_WIDTH = 200
 
+if not conf.conf['pylink'].get("debug_enabled", False):
+    raise RuntimeError("pylink::debug_enabled must be enabled to load this plugin. "
+                       "This should ONLY be used in test environments for debugging and development, "
+                       "as anyone with access to this plugin's commands can run arbitrary code as the PyLink user!")
+
 def _exec(irc, source, args, locals_dict=None):
     """<code>
 
