@@ -4,7 +4,7 @@ raw.py: Provides a 'raw' command for sending raw text to IRC.
 from pylinkirc import utils
 from pylinkirc.coremods import permissions
 from pylinkirc.log import log
-
+from pylinkirc import conf
 
 @utils.add_cmd
 def raw(irc, source, args):
@@ -12,15 +12,12 @@ def raw(irc, source, args):
 
     Sends raw text to the IRC server.
 
-    This command is not officially supported on non-Clientbot networks, where it
-    requires a separate permission."""
+    Use with caution - This command is only officially supported on Clientbot networks."""
+    if not conf.conf['pylink'].get("raw_enabled", False):
+        raise RuntimeError("Raw commands are not supported on this protocol")
 
-    if irc.protoname == 'clientbot':
-        # exec.raw is included for backwards compatibility with PyLink 1.x
-        perms = ['raw.raw', 'exec.raw']
-    else:
-        perms = ['raw.raw.unsupported_network']
-    permissions.check_permissions(irc, source, perms)
+    # exec.raw is included for backwards compatibility with PyLink 1.x
+    permissions.check_permissions(irc, source, ['raw.raw', 'exec.raw'])
 
     args = ' '.join(args)
     if not args.strip():
