@@ -4,10 +4,12 @@ hybrid.py: IRCD-Hybrid protocol module for PyLink.
 
 import time
 
-from pylinkirc import conf, utils
+from pylinkirc import conf
 from pylinkirc.classes import *
 from pylinkirc.log import log
-from pylinkirc.protocols.ts6 import *
+from pylinkirc.protocols.ts6 import TS6Protocol
+
+__all__ = ['HybridProtocol']
 
 
 # This protocol module inherits from the TS6 protocol.
@@ -129,8 +131,8 @@ class HybridProtocol(TS6Protocol):
         """Updates the ident, host, or realname of a PyLink client."""
         # https://github.com/ircd-hybrid/ircd-hybrid/blob/58323b8/modules/m_svsmode.c#L40-L103
         # parv[0] = command
-        # parv[1] = nickname <-- UID works too -GLolol
-        # parv[2] = TS <-- Of the user, not the current time. -GLolol
+        # parv[1] = nickname <-- UID works too -jlu5
+        # parv[2] = TS <-- Of the user, not the current time. -jlu5
         # parv[3] = mode
         # parv[4] = optional argument (services account, vhost)
         field = field.upper()
@@ -140,11 +142,17 @@ class HybridProtocol(TS6Protocol):
         if field == 'HOST':
             self.users[target].host = text
             # On Hybrid, it appears that host changing is actually just forcing umode
-            # "+x <hostname>" on the target. -GLolol
+            # "+x <hostname>" on the target. -jlu5
             self._send_with_prefix(self.sid, 'SVSMODE %s %s +x %s' % (target, ts, text))
         else:
             raise NotImplementedError("Changing field %r of a client is unsupported by this protocol." % field)
 
+    def oper_notice(self, source, text):
+        """
+        Send a message to all opers.
+        """
+        self._send_with_prefix(source, 'GLOBOPS :%s' % text)
+
     def set_server_ban(self, source, duration, user='*', host='*', reason='User banned'):
         """
         Sets a server ban.
@@ -209,11 +217,14 @@ class HybridProtocol(TS6Protocol):
         # Call the OPERED UP hook if +o is being added to the mode list.
         self._check_oper_status_change(uid, parsedmodes)
 
+        # Track SSL/TLS status
+        has_ssl = self.users[uid].ssl = ('+S', None) in parsedmodes
+
         # Set the account name if present
         if account:
             self.call_hooks([uid, 'CLIENT_SERVICES_LOGIN', {'text': account}])
 
-        return {'uid': uid, 'ts': ts, 'nick': nick, 'realname': realname, 'host': host, 'ident': ident, 'ip': ip}
+        return {'uid': uid, 'ts': ts, 'nick': nick, 'realname': realname, 'host': host, 'ident': ident, 'ip': ip, 'secure': has_ssl}
 
     def handle_tburst(self, numeric, command, args):
         """Handles incoming topic burst (TBURST) commands."""
@@ -253,7 +264,7 @@ class HybridProtocol(TS6Protocol):
                 # Login sequence (tested with Anope 2.0.4-git):
                 # A mode change +d accountname is used to propagate logins,
                 # before setting umode +r on the target.
-                # <- :5ANAAAAAG SVSMODE 5HYAAAAAA 1460175209 +d GL
+                # <- :5ANAAAAAG SVSMODE 5HYAAAAAA 1460175209 +d jlu5
                 # <- :5ANAAAAAG SVSMODE 5HYAAAAAA 1460175209 +r
 
                 # Logout sequence:
