@@ -5,17 +5,19 @@ inspircd.py: InspIRCd 2.0, 3.x protocol module for PyLink.
 import threading
 import time
 
-from pylinkirc import conf, utils
+from pylinkirc import conf
 from pylinkirc.classes import *
 from pylinkirc.log import log
-from pylinkirc.protocols.ts6_common import *
+from pylinkirc.protocols.ts6_common import TS6BaseProtocol
+
+__all__ = ['InspIRCdProtocol']
 
 
 class InspIRCdProtocol(TS6BaseProtocol):
 
     S2S_BUFSIZE = 0  # InspIRCd allows infinitely long S2S messages, so set bufsize to infinite
     SUPPORTED_IRCDS = ['insp20', 'insp3']
-    DEFAULT_IRCD = SUPPORTED_IRCDS[0]
+    DEFAULT_IRCD = SUPPORTED_IRCDS[1]
 
     MAX_PROTO_VER = 1205  # anything above this warns (not officially supported)
 
@@ -332,6 +334,12 @@ class InspIRCdProtocol(TS6BaseProtocol):
 
                 self.call_hooks([self.sid, 'CHGNAME',
                                    {'target': target, 'newgecos': text}])
+    def oper_notice(self, source, text):
+        """
+        Send a message to all opers.
+        """
+        # <- :70M SNONOTICE G :From jlu5: aaaaaa
+        self._send_with_prefix(self.sid, 'SNONOTICE G :From %s: %s' % (self.get_friendly_name(source), text))
 
     def numeric(self, source, numeric, target, text):
         """Sends raw numerics from a server to a remote client."""
@@ -760,7 +768,7 @@ class InspIRCdProtocol(TS6BaseProtocol):
 
     def handle_uid(self, numeric, command, args):
         """Handles incoming UID commands (user introduction)."""
-        # :70M UID 70MAAAAAB 1429934638 GL 0::1 hidden-7j810p.9mdf.lrek.0000.0000.IP gl 0::1 1429934638 +Wioswx +ACGKNOQXacfgklnoqvx :realname
+        # :70M UID 70MAAAAAB 1429934638 jlu5 0::1 hidden-7j810p.9mdf.lrek.0000.0000.IP jlu5 0::1 1429934638 +Wioswx +ACGKNOQXacfgklnoqvx :realname
         uid, ts, nick, realhost, host, ident, ip = args[0:7]
 
         ts = int(ts)
@@ -775,7 +783,8 @@ class InspIRCdProtocol(TS6BaseProtocol):
         self._check_oper_status_change(uid, parsedmodes)
 
         self.servers[numeric].users.add(uid)
-        return {'uid': uid, 'ts': ts, 'nick': nick, 'realhost': realhost, 'host': host, 'ident': ident, 'ip': ip}
+        # InspIRCd sends SSL status in the metadata command, so the info is not known at this point
+        return {'uid': uid, 'ts': ts, 'nick': nick, 'realhost': realhost, 'host': host, 'ident': ident, 'ip': ip, 'secure': None}
 
     def handle_server(self, source, command, args):
         """Handles incoming SERVER commands (introduction of servers)."""
@@ -844,10 +853,10 @@ class InspIRCdProtocol(TS6BaseProtocol):
     def handle_ftopic(self, source, command, args):
         """Handles incoming topic changes."""
         # insp2 (only used for server senders):
-        # <- :70M FTOPIC #channel 1434510754 GLo|o|!GLolol@escape.the.dreamland.ca :Some channel topic
+        # <- :70M FTOPIC #channel 1434510754 jlu5!jlu5@escape.the.dreamland.ca :Some channel topic
 
         # insp3 (used for server AND user senders):
-        # <- :3IN FTOPIC #qwerty 1556828864 1556844505 GL!gl@midnight-umk.of4.0.127.IP :1234abcd
+        # <- :3IN FTOPIC #qwerty 1556828864 1556844505 jlu5!jlu5@midnight-umk.of4.0.127.IP :1234abcd
         # <- :3INAAAAAA FTOPIC #qwerty 1556828864 1556844248 :topic text
         #           chan creation time ^          ^ topic set time (the one we want)
 
@@ -984,6 +993,8 @@ class InspIRCdProtocol(TS6BaseProtocol):
                     self._modsupport.add(module[1:])
                 else:
                     log.warning('(%s) Got unknown METADATA modules string: %r', self.name, args[-1])
+        elif args[1] == 'ssl_cert' and uid in self.users:
+            self.users[uid].ssl = True
 
     def handle_version(self, numeric, command, args):
         """
