@@ -4,53 +4,39 @@ ircs2s_common.py: Common base protocol class with functions shared by TS6 and P1
 
 import re
 import time
-from collections import defaultdict
 
-from pylinkirc import conf, utils
+from pylinkirc import conf
 from pylinkirc.classes import IRCNetwork, ProtocolError
 from pylinkirc.log import log
 
+__all__ = ['UIDGenerator', 'IRCCommonProtocol', 'IRCS2SProtocol']
 
-class IncrementalUIDGenerator():
+class UIDGenerator():
     """
-    Incremental UID Generator module, adapted from InspIRCd source:
-    https://github.com/inspircd/inspircd/blob/f449c6b296ab/src/server.cpp#L85-L156
+    Generate UIDs for IRC S2S.
     """
 
-    def __init__(self, sid):
-        if not (hasattr(self, 'allowedchars') and hasattr(self, 'length')):
-             raise RuntimeError("Allowed characters list not defined. Subclass "
-                                "%s by defining self.allowedchars and self.length "
-                                "and then calling super().__init__()." % self.__class__.__name__)
-        self.uidchars = [self.allowedchars[0]]*self.length
-        self.sid = str(sid)
-
-    def increment(self, pos=None):
-        """
-        Increments the UID generator to the next available UID.
-        """
-        # Position starts at 1 less than the UID length.
-        if pos is None:
-            pos = self.length - 1
-
-        # If we're at the last character in the list of allowed ones, reset
-        # and increment the next level above.
-        if self.uidchars[pos] == self.allowedchars[-1]:
-            self.uidchars[pos] = self.allowedchars[0]
-            self.increment(pos-1)
-        else:
-            # Find what position in the allowed characters list we're currently
-            # on, and add one.
-            idx = self.allowedchars.find(self.uidchars[pos])
-            self.uidchars[pos] = self.allowedchars[idx+1]
+    def __init__(self, uidchars, length, sid):
+        self.uidchars = uidchars  # corpus of characters to choose from
+        self.length = length  # desired length of uid part, padded with uidchars[0]
+        self.sid = str(sid)  #  server id (prefixed to every result)
+        self.counter = 0
 
     def next_uid(self):
         """
         Returns the next unused UID for the server.
         """
-        uid = self.sid + ''.join(self.uidchars)
-        self.increment()
-        return uid
+        uid = ''
+        num = self.counter
+        if num >= (len(self.uidchars) ** self.length):
+            raise RuntimeError("UID overflowed")
+        while num > 0:
+            num, index = divmod(num, len(self.uidchars))
+            uid = self.uidchars[index] + uid
+
+        self.counter += 1
+        uid = uid.rjust(self.length, self.uidchars[0])
+        return self.sid + uid
 
 class IRCCommonProtocol(IRCNetwork):
 
@@ -96,7 +82,7 @@ class IRCCommonProtocol(IRCNetwork):
                 joined_arg = ' '.join(args[idx:])[1:]  # Cut off the leading : as well
                 real_args.append(joined_arg)
                 break
-            elif arg.strip():  # Skip empty args that aren't part of the multi-word arg
+            elif arg.strip(' '):  # Skip empty args that aren't part of the multi-word arg
                 real_args.append(arg)
 
         return real_args
@@ -309,19 +295,18 @@ class IRCS2SProtocol(IRCCommonProtocol):
         args = self.parse_args(data)
 
         sender = args[0]
-        sender = sender.lstrip(':')
+        if sender.startswith(':'):
+            sender = sender[1:]
 
-        # If the sender isn't in numeric format, try to convert it automatically.
-        sender_sid = self._get_SID(sender)
-        sender_uid = self._get_UID(sender)
+            # If the sender isn't in numeric format, try to convert it automatically.
+            sender_sid = self._get_SID(sender)
+            sender_uid = self._get_UID(sender)
 
-        if sender_sid in self.servers:
-            # Sender is a server (converting from name to SID gave a valid result).
-            sender = sender_sid
-        elif sender_uid in self.users:
-            # Sender is a user (converting from name to UID gave a valid result).
-            sender = sender_uid
-        elif not (args[0].startswith(':')):
+            if sender_sid in self.servers:
+                sender = sender_sid
+            elif sender_uid in self.users:
+                sender = sender_uid
+        else:
             # No sender prefix; treat as coming from uplink IRCd.
             sender = self.uplink
             args.insert(0, sender)
@@ -342,7 +327,7 @@ class IRCS2SProtocol(IRCCommonProtocol):
 
         if command == 'ENCAP':
             # Special case for TS6 encapsulated commands (ENCAP), in forms like this:
-            # <- :00A ENCAP * SU 42XAAAAAC :GLolol
+            # <- :00A ENCAP * SU 42XAAAAAC :jlu5
             command = args[1]
             args = args[2:]
             log.debug("(%s) Rewriting incoming ENCAP to command %s (args: %s)", self.name, command, args)
@@ -385,6 +370,12 @@ class IRCS2SProtocol(IRCCommonProtocol):
         # handle_part() does that just fine.
         self.handle_part(target, 'KICK', [channel])
 
+    def oper_notice(self, source, text):
+        """
+        Send a message to all opers.
+        """
+        self._send_with_prefix(source, 'WALLOPS :%s' % text)
+
     def numeric(self, source, numeric, target, text):
         """Sends raw numerics from a server to a remote client. This is used for WHOIS replies."""
         # Mangle the target for IRCds that require it.
@@ -506,7 +497,7 @@ class IRCS2SProtocol(IRCCommonProtocol):
             return
 
         # TS6-style kills look something like this:
-        # <- :GL KILL 38QAAAAAA :hidden-1C620195!GL (test)
+        # <- :jlu5 KILL 38QAAAAAA :hidden-1C620195!jlu5 (test)
         # What we actually want is to format a pretty kill message, in the form
         # "Killed (killername (reason))".
 
@@ -529,9 +520,9 @@ class IRCS2SProtocol(IRCCommonProtocol):
             # XXX: this does create a convoluted kill string if we want to forward kills
             # over relay.
             # InspIRCd:
-            # <- :1MLAAAAA1 KILL 0ALAAAAAC :Killed (GL (test))
+            # <- :1MLAAAAA1 KILL 0ALAAAAAC :Killed (jlu5 (test))
             # ngIRCd:
-            # <- :GL KILL PyLink-devel :KILLed by GL: ?
+            # <- :jlu5 KILL PyLink-devel :KILLed by jlu5: ?
             killmsg = args[1]
 
         return {'target': killed, 'text': killmsg, 'userdata': userdata}
@@ -573,7 +564,7 @@ class IRCS2SProtocol(IRCCommonProtocol):
         # <- :70MAAAAAA MODE 70MAAAAAA -i+xc
 
         # P10:
-        # <- ABAAA M GL -w
+        # <- ABAAA M jlu5 -w
         # <- ABAAA M #test +v ABAAB 1460747615
         # <- ABAAA OM #test +h ABAAA
         target = self._get_UID(args[0])
@@ -683,10 +674,14 @@ class IRCS2SProtocol(IRCCommonProtocol):
         # TS6:
         # <- :1SRAAGB4T QUIT :Quit: quit message goes here
         # P10:
-        # <- ABAAB Q :Killed (GL_ (bangbang))
+        # <- ABAAB Q :Killed (jlu5_ (bangbang))
         userdata = self._remove_client(numeric)
         if userdata:
-            return {'text': args[0], 'userdata': userdata}
+            try:
+                reason = args[0]
+            except IndexError:
+                reason = ''
+            return {'text': reason, 'userdata': userdata}
 
     def handle_stats(self, numeric, command, args):
         """Handles the IRC STATS command."""
