@@ -3,6 +3,8 @@ p10.py: P10 protocol module for PyLink, supporting Nefarious IRCu and others.
 """
 
 import base64
+import socket
+import string
 import struct
 import time
 from ipaddress import ip_address
@@ -12,14 +14,16 @@ from pylinkirc.classes import *
 from pylinkirc.log import log
 from pylinkirc.protocols.ircs2s_common import *
 
+__all__ = ['P10Protocol']
 
-class P10UIDGenerator(IncrementalUIDGenerator):
-     """Implements an incremental P10 UID Generator."""
 
-     def __init__(self, sid):
-         self.allowedchars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789[]'
-         self.length = 3
-         super().__init__(sid)
+class P10UIDGenerator(UIDGenerator):
+    """Implements a P10 UID Generator."""
+
+    def __init__(self, sid):
+        uidchars = string.ascii_uppercase + string.ascii_lowercase + string.digits + '[]'
+        length = 3
+        super().__init__(uidchars, length, sid)
 
 def p10b64encode(num, length=2):
     """
@@ -195,7 +199,7 @@ class P10Protocol(IRCS2SProtocol):
     @staticmethod
     def decode_p10_ip(ip):
         """Decodes a P10 IP."""
-        # Many thanks to Jobe @ evilnet for the code on what to do here. :) -GL
+        # Many thanks to Jobe @ evilnet for the code on what to do here. :) -jlu5
 
         if len(ip) == 6:  # IPv4
             # Pad the characters with two \x00's (represented in P10 B64 as AA)
@@ -403,7 +407,7 @@ class P10Protocol(IRCS2SProtocol):
 
     def kill(self, numeric, target, reason):
         """Sends a kill from a PyLink client/server."""
-        # <- ABAAA D AyAAA :nefarious.midnight.vpn!GL (test)
+        # <- ABAAA D AyAAA :nefarious.midnight.vpn!jlu5 (test)
 
         if (not self.is_internal_client(numeric)) and \
                 (not self.is_internal_server(numeric)):
@@ -460,7 +464,7 @@ class P10Protocol(IRCS2SProtocol):
 
     def mode(self, numeric, target, modes, ts=None):
         """Sends mode changes from a PyLink client/server."""
-        # <- ABAAA M GL -w
+        # <- ABAAA M jlu5 -w
         # <- ABAAA M #test +v ABAAB 1460747615
 
         if (not self.is_internal_client(numeric)) and \
@@ -491,7 +495,7 @@ class P10Protocol(IRCS2SProtocol):
             real_target = target
         else:
             assert target in self.users, "Unknown mode target %s" % target
-            # P10 uses nicks in user MODE targets, NOT UIDs. ~GL
+            # P10 uses nicks in user MODE targets, NOT UIDs. ~jlu5
             real_target = self.users[target].nick
 
         self.apply_modes(target, modes)
@@ -507,7 +511,7 @@ class P10Protocol(IRCS2SProtocol):
 
     def nick(self, numeric, newnick):
         """Changes the nick of a PyLink client."""
-        # <- ABAAA N GL_ 1460753763
+        # <- ABAAA N jlu5_ 1460753763
         if not self.is_internal_client(numeric):
             raise LookupError('No such PyLink client exists.')
 
@@ -520,9 +524,15 @@ class P10Protocol(IRCS2SProtocol):
     def numeric(self, source, numeric, target, text):
         """Sends raw numerics from a server to a remote client. This is used for WHOIS
         replies."""
-        # <- AB 311 AyAAA GL ~gl nefarious.midnight.vpn * :realname
+        # <- AB 311 AyAAA jlu5 ~jlu5 nefarious.midnight.vpn * :realname
         self._send_with_prefix(source, '%s %s %s' % (numeric, target, text))
 
+    def oper_notice(self, source, text):
+        """
+        Send a message to all opers.
+        """
+        self._send_with_prefix(source, 'WA :%s' % text)
+
     def part(self, client, channel, reason=None):
         """Sends a part from a PyLink client."""
 
@@ -555,7 +565,7 @@ class P10Protocol(IRCS2SProtocol):
         assert not (user == host == '*'), "Refusing to set ridiculous ban on *@*"
 
         # https://github.com/evilnet/nefarious2/blob/master/doc/p10.txt#L535
-        # <- ABAAA GL * +test@test.host 30 1500300185 1500300215 :haha, you're banned now!!!!1
+        # <- ABAAA jlu5 * +test@test.host 30 1500300185 1500300215 :haha, you're banned now!!!!1
         currtime = int(time.time())
 
         if duration == 0 or duration > GLINE_MAX_EXPIRE:
@@ -744,7 +754,7 @@ class P10Protocol(IRCS2SProtocol):
 
     def topic(self, source, target, text):
         """Sends a TOPIC change from a PyLink client or server."""
-        # <- ABAAA T #test GL!~gl@nefarious.midnight.vpn 1460852591 1460855795 :blah
+        # <- ABAAA T #test jlu5!~jlu5@nefarious.midnight.vpn 1460852591 1460855795 :blah
         # First timestamp is channel creation time, second is current time,
         if (not self.is_internal_client(source)) and (not self.is_internal_server(source)):
             raise LookupError('No such PyLink client/server exists.')
@@ -812,6 +822,16 @@ class P10Protocol(IRCS2SProtocol):
 
     ### HANDLERS
 
+    def handle_events(self, data):
+        """
+        Events handler for the P10 protocol. This is mostly the same as RFC1459, with extra handling
+        for the fact that P10 does not send source numerics prefixed with a ":".
+        """
+        # After the initial PASS & SERVER message, every following message should be prefixed
+        if self.uplink and not data.startswith(":"):
+            data = ':' + data
+        return super().handle_events(data)
+
     def post_connect(self):
         """Initializes a connection to a server."""
         ts = self.start_ts
@@ -826,7 +846,7 @@ class P10Protocol(IRCS2SProtocol):
         # 4 <link TS>
         # 5 <protocol>
         # 6 <numeric of new server><max client numeric>
-        # 7 <flags> <-- Mark ourselves as a service with IPv6 support (+s & +6) -GLolol
+        # 7 <flags> <-- Mark ourselves as a service with IPv6 support (+s & +6) -jlu5
         # -1 <description of new server>
 
         name = self.serverdata["hostname"]
@@ -915,7 +935,7 @@ class P10Protocol(IRCS2SProtocol):
     def handle_nick(self, source, command, args):
         """Handles the NICK command, used for user introductions and nick changes."""
         if len(args) > 2:
-            # <- AB N GL 1 1460673049 ~gl nefarious.midnight.vpn +iw B]AAAB ABAAA :realname
+            # <- AB N jlu5 1 1460673049 ~jlu5 nefarious.midnight.vpn +iw B]AAAB ABAAA :realname
 
             nick = args[0]
             self._check_nick_collision(nick)
@@ -932,6 +952,7 @@ class P10Protocol(IRCS2SProtocol):
                       ident, host, realname, realhost, ip)
 
             uobj = self.users[uid] = User(self, nick, ts, uid, source, ident, host, realname, realhost, ip)
+            uobj.ssl = False
             self.servers[source].users.add(uid)
 
             # https://github.com/evilnet/nefarious2/blob/master/doc/p10.txt#L708
@@ -949,15 +970,18 @@ class P10Protocol(IRCS2SProtocol):
                         accountname = modepair[1].split(':', 1)[0]
                         self.call_hooks([uid, 'CLIENT_SERVICES_LOGIN', {'text': accountname}])
 
+                    elif modepair[0][-1] == self.umodes.get('ssl'):  # track SSL status where available
+                        uobj.ssl = True
+
                 # Call the OPERED UP hook if +o is being added to the mode list.
                 self._check_oper_status_change(uid, parsedmodes)
 
             self._check_cloak_change(uid)
 
-            return {'uid': uid, 'ts': ts, 'nick': nick, 'realhost': realhost, 'host': host, 'ident': ident, 'ip': ip, 'parse_as': 'UID'}
+            return {'uid': uid, 'ts': ts, 'nick': nick, 'realhost': realhost, 'host': host, 'ident': ident, 'ip': ip, 'parse_as': 'UID', 'secure': uobj.ssl}
 
         else:
-            # <- ABAAA N GL_ 1460753763
+            # <- ABAAA N jlu5_ 1460753763
             oldnick = self.users[source].nick
             newnick = self.users[source].nick = args[0]
 
@@ -1037,7 +1061,7 @@ class P10Protocol(IRCS2SProtocol):
         # -> X3 Z Channels.CollectiveIRC.Net 1460745823.89510 0 1460745823.089840
         # Arguments of a PONG: our server hostname, the original TS of PING,
         #                      difference between PING and PONG in seconds, the current TS.
-        # Why is this the way it is? I don't know... -GL
+        # Why is this the way it is? I don't know... -jlu5
 
         target = args[1]
         sid = self._get_SID(target)
@@ -1213,7 +1237,7 @@ class P10Protocol(IRCS2SProtocol):
 
     def handle_topic(self, source, command, args):
         """Handles TOPIC changes."""
-        # <- ABAAA T #test GL!~gl@nefarious.midnight.vpn 1460852591 1460855795 :blah
+        # <- ABAAA T #test jlu5!~jlu5@nefarious.midnight.vpn 1460852591 1460855795 :blah
         channel = args[0]
         topic = args[-1]
 
@@ -1266,7 +1290,7 @@ class P10Protocol(IRCS2SProtocol):
         target = args[0]
 
         if self.serverdata.get('use_extended_accounts'):
-            # Registration: <- AA AC ABAAA R GL 1459019072
+            # Registration: <- AA AC ABAAA R jlu5 1459019072
             # Logout: <- AA AC ABAAA U
 
             # 1 <target user numeric>
