@@ -8,7 +8,9 @@ import time
 from pylinkirc import conf, utils
 from pylinkirc.classes import *
 from pylinkirc.log import log
-from pylinkirc.protocols.ts6_common import *
+from pylinkirc.protocols.ts6_common import TS6BaseProtocol
+
+__all__ = ['TS6Protocol']
 
 
 class TS6Protocol(TS6BaseProtocol):
@@ -21,7 +23,7 @@ class TS6Protocol(TS6BaseProtocol):
                                                              else 'charybdis')
         self._ircd = self._ircd.lower()
         if self._ircd not in self.SUPPORTED_IRCDS:
-            log.warning("(%s) Unsupported IRCd %r; falling back to 'charybdis' instead", self.name, target_ircd)
+            log.warning("(%s) Unsupported IRCd %r; falling back to 'charybdis' instead", self.name, self._ircd)
             self._ircd = 'charybdis'
 
         self._can_chghost = False
@@ -115,6 +117,15 @@ class TS6Protocol(TS6BaseProtocol):
         self._channels[channel].users.add(client)
         self.users[client].channels.add(channel)
 
+    def oper_notice(self, source, text):
+        """
+        Send a message to all opers.
+        """
+        if self.is_internal_server(source):
+            # Charybdis TS6 only allows OPERWALL from users
+            source = self.pseudoclient.uid
+        self._send_with_prefix(source, 'OPERWALL :%s' % text)
+
     def sjoin(self, server, channel, users, ts=None, modes=set()):
         """Sends an SJOIN for a group of users to a channel.
 
@@ -315,19 +326,19 @@ class TS6Protocol(TS6BaseProtocol):
                 'quiet': 'q', 'redirect': 'f', 'freetarget': 'F',
                 'joinflood': 'j', 'largebanlist': 'L', 'permanent': 'P',
                 'noforwards': 'Q', 'stripcolor': 'c', 'allowinvite':
-                'g', 'opmoderated': 'z', 'noctcp': 'C', 'ssl': 'Z',
+                'g', 'opmoderated': 'z', 'noctcp': 'C',
                 # charybdis modes provided by extensions
                 'operonly': 'O', 'adminonly': 'A', 'sslonly': 'S',
                 'nonotice': 'T',
-                '*A': 'beIq', '*B': 'k', '*C': 'lfj', '*D': 'mnprstFLPQcgzCZOAST'
+                '*A': 'beIq', '*B': 'k', '*C': 'lfj', '*D': 'mnprstFLPQcgzCOAST'
             })
             self.umodes.update({
                 'deaf': 'D', 'servprotect': 'S', 'admin': 'a',
                 'invisible': 'i', 'oper': 'o', 'wallops': 'w',
                 'snomask': 's', 'noforward': 'Q', 'regdeaf': 'R',
                 'callerid': 'g', 'operwall': 'z', 'locops': 'l',
-                'cloak': 'x', 'override': 'p',
-                '*A': '', '*B': '', '*C': '', '*D': 'DSaiowsQRgzlxp'
+                'cloak': 'x', 'override': 'p', 'ssl': 'Z',
+                '*A': '', '*B': '', '*C': '', '*D': 'DSaiowsQRgzlxpZ'
             })
 
             # Charybdis extbans
@@ -429,7 +440,7 @@ class TS6Protocol(TS6BaseProtocol):
 
         if args[0] != self.serverdata['recvpass']:
             # Check if recvpass is correct
-            raise ProtocolError('Recvpass from uplink server %s does not match configuration!' % servername)
+            raise ProtocolError('Recvpass from uplink server %r does not match configuration!' % numeric)
 
         if args[1] != 'TS' and args[2] != '6':
             raise ProtocolError("Remote protocol version is too old! Is this even TS6?")
@@ -573,7 +584,7 @@ class TS6Protocol(TS6BaseProtocol):
 
     def handle_euid(self, numeric, command, args):
         """Handles incoming EUID commands (user introduction)."""
-        # <- :42X EUID GL 1 1437505322 +ailoswz ~gl 127.0.0.1 127.0.0.1 42XAAAAAB * * :realname
+        # <- :42X EUID jlu5 1 1437505322 +ailoswz ~jlu5 127.0.0.1 127.0.0.1 42XAAAAAB * * :realname
         nick = args[0]
         self._check_nick_collision(nick)
         ts, modes, ident, host, ip, uid, realhost, accountname, realname = args[2:11]
@@ -603,7 +614,11 @@ class TS6Protocol(TS6BaseProtocol):
         if accountname != "*":
             self.call_hooks([uid, 'CLIENT_SERVICES_LOGIN', {'text': accountname}])
 
-        return {'uid': uid, 'ts': ts, 'nick': nick, 'realhost': realhost, 'host': host, 'ident': ident, 'ip': ip}
+        # charybdis and derivatives have a usermode (+Z) to mark SSL connections
+        # ratbox doesn't appear to have this
+        has_ssl = self.users[uid].ssl = ('+%s' % self.umodes.get('ssl'), None) in parsedmodes
+
+        return {'uid': uid, 'ts': ts, 'nick': nick, 'realhost': realhost, 'host': host, 'ident': ident, 'ip': ip, 'secure': has_ssl}
 
     def handle_uid(self, numeric, command, args):
         """Handles legacy user introductions (UID)."""
@@ -642,7 +657,7 @@ class TS6Protocol(TS6BaseProtocol):
 
             return
 
-        # <- :services.int SERVER a.bc 2 :(H) [GL] a
+        # <- :services.int SERVER a.bc 2 :(H) [jlu5] a
         return super().handle_server(numeric, command, args)
 
     def handle_tmode(self, numeric, command, args):
@@ -660,7 +675,7 @@ class TS6Protocol(TS6BaseProtocol):
 
     def handle_tb(self, numeric, command, args):
         """Handles incoming topic burst (TB) commands."""
-        # <- :42X TB #chat 1467427448 GL!~gl@127.0.0.1 :test
+        # <- :42X TB #chat 1467427448 jlu5!~jlu5@127.0.0.1 :test
         channel = args[0]
         ts = args[1]
         setter = args[2]
@@ -671,7 +686,7 @@ class TS6Protocol(TS6BaseProtocol):
 
     def handle_etb(self, numeric, command, args):
         """Handles extended topic burst (ETB)."""
-        # <- :00AAAAAAC ETB 0 #test 1470021157 GL :test | abcd
+        # <- :00AAAAAAC ETB 0 #test 1470021157 jlu5 :test | abcd
         # Same as TB, with extra TS and extensions arguments.
         channel = args[1]
         ts = args[2]
@@ -708,7 +723,7 @@ class TS6Protocol(TS6BaseProtocol):
         the administrator that certain extensions should be loaded for the best
         compatibility.
         """
-        # <- :charybdis.midnight.vpn 472 GL|devel O :is an unknown mode char to me
+        # <- :charybdis.midnight.vpn 472 jlu5|devel O :is an unknown mode char to me
         badmode = args[1]
         reason = args[-1]
         setter = args[0]
@@ -725,7 +740,7 @@ class TS6Protocol(TS6BaseProtocol):
         """
         Handles SU, which is used for setting login information.
         """
-        # <- :00A ENCAP * SU 42XAAAAAC :GLolol
+        # <- :00A ENCAP * SU 42XAAAAAC :jlu5
         # <- :00A ENCAP * SU 42XAAAAAC
         try:
             account = args[1]  # Account name is being set
@@ -744,7 +759,7 @@ class TS6Protocol(TS6BaseProtocol):
 
     def handle_realhost(self, uid, command, args):
         """Handles real host propagation."""
-        log.debug('(%s) Got REALHOST %s for %s', args[0], uid)
+        log.debug('(%s) Got REALHOST %s for %s', self.name, args[0], uid)
         self.users[uid].realhost = args[0]
 
     def handle_login(self, uid, command, args):
