@@ -5,11 +5,13 @@ ts6_common.py: Common base protocol class with functions shared by the UnrealIRC
 import string
 import time
 
-from pylinkirc import conf, structures, utils
+from pylinkirc import conf, structures
 from pylinkirc.classes import *
 from pylinkirc.log import log
 from pylinkirc.protocols.ircs2s_common import *
 
+__all__ = ['TS6BaseProtocol']
+
 
 class TS6SIDGenerator():
     """
@@ -85,18 +87,16 @@ class TS6SIDGenerator():
         sid = ''.join(self.output)
         return sid
 
-class TS6UIDGenerator(IncrementalUIDGenerator):
+class TS6UIDGenerator(UIDGenerator):
      """Implements an incremental TS6 UID Generator."""
 
      def __init__(self, sid):
-         # Define the options for IncrementalUIDGenerator, and then
-         # initialize its functions.
          # TS6 UIDs are 6 characters in length (9 including the SID).
          # They go from ABCDEFGHIJKLMNOPQRSTUVWXYZ -> 0123456789 -> wrap around:
          # e.g. AAAAAA, AAAAAB ..., AAAAA8, AAAAA9, AAAABA, etc.
-         self.allowedchars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456879'
-         self.length = 6
-         super().__init__(sid)
+         uidchars = string.ascii_uppercase + string.digits
+         length = 6
+         super().__init__(uidchars, length, sid)
 
 class TS6BaseProtocol(IRCS2SProtocol):
     def __init__(self, *args, **kwargs):
@@ -216,7 +216,7 @@ class TS6BaseProtocol(IRCS2SProtocol):
 
     def handle_nick(self, numeric, command, args):
         """Handles incoming NICK changes."""
-        # <- :70MAAAAAA NICK GL-devel 1434744242
+        # <- :70MAAAAAA NICK jlu5-devel 1434744242
         oldnick = self.users[numeric].nick
         newnick = self.users[numeric].nick = args[0]
 
@@ -247,7 +247,7 @@ class TS6BaseProtocol(IRCS2SProtocol):
 
     def handle_server(self, numeric, command, args):
         """Handles the SERVER command, used for introducing older (TS5) servers."""
-        # <- :services.int SERVER a.bc 2 :(H) [GL] test jupe
+        # <- :services.int SERVER a.bc 2 :(H) [jlu5] test jupe
         servername = args[0].lower()
         sdesc = args[-1]
         self.servers[servername] = Server(self, numeric, servername, desc=sdesc)
@@ -270,5 +270,5 @@ class TS6BaseProtocol(IRCS2SProtocol):
         # This is rewritten to SVSNICK with args ['902AAAAAB', 'Guest53593', '1468299404']
 
         # UnrealIRCd:
-        # <- :services.midnight.vpn SVSNICK GL Guest87795 1468303726
+        # <- :services.midnight.vpn SVSNICK jlu5 Guest87795 1468303726
         return {'target': self._get_UID(args[0]), 'newnick': args[1]}
