@@ -16,6 +16,13 @@ from copy import copy, deepcopy
 from . import conf
 from .log import log
 
+__all__ = ['KeyedDefaultdict', 'CopyWrapper', 'CaseInsensitiveFixedSet',
+          'CaseInsensitiveDict', 'IRCCaseInsensitiveDict',
+          'CaseInsensitiveSet', 'IRCCaseInsensitiveSet',
+          'CamelCaseToSnakeCase', 'DataStore', 'JSONDataStore',
+          'PickleDataStore']
+
+
 _BLACKLISTED_COPY_TYPES = []
 
 class KeyedDefaultdict(collections.defaultdict):
@@ -25,7 +32,7 @@ class KeyedDefaultdict(collections.defaultdict):
     def __missing__(self, key):
         if self.default_factory is None:
             # If there is no default factory, just let defaultdict handle it
-            super().__missing__(self, key)
+            super().__missing__(key)
         else:
             value = self[key] = self.default_factory(key)
             return value
@@ -201,7 +208,12 @@ class DataStore:
     Generic database class. Plugins should use a subclass of this such as JSONDataStore or
     PickleDataStore.
     """
-    def __init__(self, name, filename, save_frequency=None, default_db=None):
+    def __init__(self, name, filename, save_frequency=None, default_db=None, data_dir=None):
+        if data_dir is None:
+            data_dir = conf.conf['pylink'].get('data_dir', '')
+
+        filename = os.path.join(data_dir, filename)
+
         self.name = name
         self.filename = filename
         self.tmp_filename = filename + '.tmp'
